# [`bunny-sdk`](https://bunny-launcher.com/bunny-sdk/python)

![PyPI - Version](https://img.shields.io/pypi/v/bunny-sdk?color=blue)

<!-- poetry folder name uses underscores https://github.com/python-poetry/poetry/issues/8942#issuecomment-1925761531 -->
<!-- poetry pypi authentication https://www.digitalocean.com/community/tutorials/how-to-publish-python-packages-to-pypi-using-poetry-on-ubuntu-22-04 -->

## Install

```shell
pip install bunny-sdk
```

## Documentation

Please read the [docs](https://bunny-launcher.com/bunny-sdk/python) for usage and examples.

## Contributing

- `brew install pipx`
- `pipx ensurepath`
- `pipx install poetry==1.8.2`
- `poetry install`
- `source .venv/bin/activate`
- `pip install -e .`
- `poetry build`
- `git add -A`
- `git commit -m "message"`
- `git push`
- `poetry publish`
